@@ -4,6 +4,8 @@ from .atf_file_type import AtfFileType
 from .hlt_call_doctor import HltCallDoctor
 from .hlt_call_doctor_status import HltCallDoctorStatus
 from .hlt_doc_prvd import HltDocPrvd
+from .hlt_doctor_time_table import HltDoctorTimeTable
+from .hlt_doctor_visit_table import HltDoctorVisitTable
 from .hlt_lpu_doctor import HltLpuDoctor
 from .hlt_med_record import HltMedRecord
 from .hlt_mkab import HltMkab, Gender
