@@ -1,9 +1,14 @@
 # noinspection PyUnresolvedReferences
 import uuid
 
+from django.db import models
 # noinspection PyUnresolvedReferences
 from django.utils import timezone
-from django.db import models
+
+FK_DEFAULT = {
+    'on_delete'   : models.DO_NOTHING,
+    'related_name': '+'
+}
 
 
 class BaseModel(models.Model):
