@@ -7,10 +7,10 @@ class HltUchastok(BaseModel):
 
     caption = models.CharField(db_column='UchastoCaption', max_length=500)
     code = models.CharField(db_column='CODE', max_length=6)
-    doctor = models.ForeignKey('HltLpuDoctor', models.DO_NOTHING, related_name='+', db_column='rf_LPUDoctorID')
-    doc_prvd = models.ForeignKey('HltDocPrvd', models.DO_NOTHING, '+', db_column='rf_DocPRVDID')
+    doctor = models.ForeignKey('HltLpuDoctor', db_column='rf_LPUDoctorID', **FK_DEFAULT)
+    doc_prvd = models.ForeignKey('HltDocPrvd', db_column='rf_DocPRVDID', **FK_DEFAULT)
     type_uid = models.IntegerField(db_column='rf_kl_TypeUID')
-    lpu = models.ForeignKey('OmsLpu', models.DO_NOTHING, related_name='+', db_column='rf_LPUID')
+    lpu = models.ForeignKey('OmsLpu', db_column='rf_LPUID', **FK_DEFAULT)
     is_closed = models.IntegerField(db_column='isClosed')
     code_smo = models.CharField(db_column='CodeSMO', max_length=6)
     date_begin = models.DateTimeField(db_column='DateBegin')
